@@ -20,7 +20,6 @@ extern "C" {
 #if defined(MS_WIN32) && defined(_MSC_VER)
 /* the __MPN determination in stock gmp.h doesn't work, so...: */
 #    define __MPN(x) __gmpn_##x
-#    define _GMP_H_HAVE_FILE
 #    define _PROTO(x) x
 #define inline __inline
 #endif
@@ -34,11 +33,16 @@ extern "C" {
 /* ensure 2.5 compatibility */
 #if PY_VERSION_HEX < 0x02050000
 typedef int Py_ssize_t;
+#define PY_FORMAT_SIZE_T ""
 #endif
 #ifndef Py_TPFLAGS_HAVE_INDEX
 #define Py_TPFLAGS_HAVE_INDEX 0
 #endif
 
+#if PY_VERSION_HEX < 0x030200A3
+typedef long Py_hash_t;
+typedef unsigned long Py_uhash_t;
+#endif
 
 /* Header file for gmpy */
 typedef struct {
@@ -57,7 +61,7 @@ typedef struct {
 typedef struct {
     mpob ob;
     mpf_t f;
-    unsigned int rebits;
+    size_t rebits;
 } PympfObject;
 
 /* #define MPOBCAL(obj) ((mpob*)obj)->callable */
@@ -84,7 +88,7 @@ typedef struct {
 
 #define Pympf_new_NUM 5
 #define Pympf_new_RETURN PympfObject *
-#define Pympf_new_PROTO (unsigned int bits)
+#define Pympf_new_PROTO (size_t bits)
 
 #define Pympz_dealloc_NUM 6
 #define Pympz_dealloc_RETURN void
@@ -132,6 +136,7 @@ static Pympf_new_RETURN Pympf_new Pympf_new_PROTO;
 static Pympf_dealloc_RETURN Pympf_dealloc Pympf_dealloc_PROTO;
 static Pympf_convert_arg_RETURN Pympf_convert_arg Pympf_convert_arg_PROTO;
 
+#if PY_MAJOR_VERSION < 3
 #define export_gmpy(m) { \
       PyObject *d; \
       static void *Pygmpy_API[Pygmpy_API_pointers]; \
@@ -155,6 +160,7 @@ static Pympf_convert_arg_RETURN Pympf_convert_arg Pympf_convert_arg_PROTO;
       d = PyModule_GetDict(m);\
       PyDict_SetItemString(d, "_C_API", c_api_object);\
     }
+#endif
 
 #else
 /* This section is used in other C-coded modules that use gmpy's API */
@@ -190,6 +196,7 @@ static void **Pygmpy_API;
 #define Pympf_convert_arg \
   (*(Pympf_convert_arg_RETURN (*)Pympf_convert_arg_PROTO) Pygmpy_API[Pympf_convert_arg_NUM])
 
+#if PY_MAJOR_VERSION < 3
 #define import_gmpy() \
      {  \
        PyObject *module = PyImport_ImportModule("gmpy");\
@@ -201,7 +208,14 @@ static void **Pygmpy_API;
          } \
        } \
      }
-
+#else
+static int
+import_gmpy(void)
+{
+    Pygmpy_API = (void **)PyCapsule_Import("gmpy._C_API", 0);
+    return (Pygmpy_API != NULL) ? 0 : -1;
+}
+#endif
 #endif
 
 #ifdef __cplusplus
