@@ -2,7 +2,7 @@
  *
  * Miscellaneous module-level functions.
  *
- * This file should be considered part of gmpy.c
+ * This file should be considered part of gmpy.c.
  */
 
 /* Return license information. */
@@ -130,10 +130,10 @@ Note: only useful to debug gmpy's own internals!\n\
 static PyObject *
 Pygmpy_set_debug(PyObject *self, PyObject *args)
 {
-    long old = options.debug;
+    int old = options.debug;
 
-    ONE_ARG("set_debug", "l", &options.debug);
-    return Py_BuildValue("l", old);
+    ONE_ARG("set_debug", "i", &options.debug);
+    return Py_BuildValue("i", old);
 }
 
 static char doc_set_tagoff[]="\
@@ -161,9 +161,9 @@ static PyObject *
 Pygmpy_set_minprec(PyObject *self, PyObject *args)
 {
     long old = options.minprec;
-    int i;
+    long i;
 
-    ONE_ARG("set_minprec", "i", &i);
+    ONE_ARG("set_minprec", "l", &i);
     if(i<0) {
         PyErr_SetString(PyExc_ValueError,
             "minimum precision must be >= 0");
