@@ -7,6 +7,8 @@
  *   Pympz_FROM_MPZ(mpz_t)
  *   Pympq_FROM_MPQ(mpq_t)
  *   Pympf_FROM_MPF(mpf_t)
+ *
+ * This file should be considered part of gmpy.c.
  */
 
 #ifdef FALSE
@@ -32,8 +34,7 @@ mpz_set_PyInt(mpz_t rop, PyObject *obj)
 static void
 mpf_normalize(mpf_t op)
 {
-    long size, prec, toclear, temp;
-    int i;
+    Py_ssize_t size, prec, toclear, temp, i;
     mp_limb_t bit1, rem, carry;
 
     prec = mpf_get_prec(op);
@@ -50,7 +51,7 @@ mpf_normalize(mpf_t op)
         fprintf(stderr, "prec %ld size %ld toclear %ld carry %ld\n",
                prec, size, toclear, carry);
         for(i=0; i<size; i++)
-            fprintf(stderr,"[%d]=%lx\n", i, op->_mp_d[i]);
+            fprintf(stderr,"[%zd]=%lx\n", i, op->_mp_d[i]);
     }
     temp = toclear;
     if(temp>0) {
@@ -71,7 +72,7 @@ mpf_normalize(mpf_t op)
     }
     if(options.debug) {
         for(i=0; i<size; i++)
-            fprintf(stderr,"[%d]=%lx\n", i, op->_mp_d[i]);
+            fprintf(stderr,"[%zd]=%lx\n", i, op->_mp_d[i]);
     }
 }
 
