@@ -1,6 +1,6 @@
 r'''
 >>> gmpy.version()
-'1.10'
+'1.17'
 >>>
 '''
 
@@ -30,16 +30,16 @@ test_modules = (gmpy_test_cvr, gmpy_test_rnd, gmpy_test_mpf,
     gmpy_test_mpq, gmpy_test_mpz, gmpy_test_dec)
 
 _g = gmpy
-writeln("Unit tests for gmpy 1.10")
+writeln("Unit tests for gmpy 1.17")
 writeln("    on Python %s" % sys.version)
 if _g.gmp_version():
-    writeln("Testing gmpy %s (GMP %s), default caching (%s, %s, %s)" % (
-            (_g.version(), _g.gmp_version(), _g.get_zcache(),
-            _g.get_qcache(), _g.get_fcache())))
+    writeln("Testing gmpy %s (GMP %s), default caching (%s, %s)" % (
+            (_g.version(), _g.gmp_version(), _g.get_cache()[0],
+            _g.get_cache()[1])))
 else:
-    writeln("Testing gmpy %s (MPIR %s), default caching (%s, %s, %s)" % (
-            (_g.version(), _g.mpir_version(), _g.get_zcache(),
-            _g.get_qcache(), _g.get_fcache())))
+    writeln("Testing gmpy %s (MPIR %s), default caching (%s, %s)" % (
+            (_g.version(), _g.mpir_version(), _g.get_cache()[0],
+            _g.get_cache()[1])))
 
 
 pf, pt = 0, 0
