@@ -1,13 +1,13 @@
-# partial unit test for gmpy 1.10 extra cover
+# partial unit test for gmpy extra cover
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.10
+
 r'''
->>> print int(_g.gmp_version()[:3] in ('4.3', '4.2', '4.1', '4.0', ''))
+>>> print int(_g.gmp_version()[:3] in ('5.0', '4.3', ''))
 1
->>> print int(_g.mpir_version()[:3] in ('', '0.9', '1.0', '1.1', '1.2', '1.3'))
+>>> print int(_g.mpir_version()[:3] in ('2.3', '2.4', '2.5', ''))
 1
 >>> _g.version()
-'1.10'
+'1.17'
 >>> int('gmpy.c' in _g._cvsid())
 1
 '''
@@ -87,48 +87,40 @@ __test__['user_errors']=\
 r'''
 >>> _g.version(23)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes exactly 0 arguments (1 given)
+  ...
+TypeError: version expects 0 arguments
 >>> _g.gmp_version(23)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes exactly 0 arguments (1 given)
->>> _g.get_zcache(23)
+  ...
+TypeError: gmp_version expects 0 arguments
+>>> _g.get_cache(23)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes exactly 0 arguments (1 given)
->>> _g.set_zcache(2000)
+  ...
+TypeError: get_cache expects 0 arguments
+>>> _g.set_cache()
 Traceback (most recent call last):
-  File "<string>", line 1, in ?
+  ...
+TypeError: function takes exactly 2 arguments (0 given)
+>>> _g.set_cache(200)
+Traceback (most recent call last):
+  ...
+TypeError: function takes exactly 2 arguments (1 given)
+>>> _g.set_cache(200,-23)
+Traceback (most recent call last):
+  ...
+ValueError: object size must between 0 and 16384
+>>> _g.set_cache(2000,256)
+Traceback (most recent call last):
+  ...
 ValueError: cache must between 0 and 1000
->>> _g.set_zcache(-23)
+>>> _g.set_cache(-23,256)
 Traceback (most recent call last):
-  File "<string>", line 1, in ?
+  ...
 ValueError: cache must between 0 and 1000
->>> _g.get_qcache(23)
+>>> _g.set_cache(200,256000)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes exactly 0 arguments (1 given)
->>> _g.set_qcache(2000)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: cache must between 0 and 1000
->>> _g.set_qcache(-42)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: cache must between 0 and 1000
->>> _g.get_fcache(23)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes exactly 0 arguments (1 given)
->>> _g.set_fcache(2000)
-Traceback (most recent call last):
-  File "<string>", line 1, in ?
-ValueError: cache must between 0 and 1000
->>> _g.set_fcache(-23)
-Traceback (most recent call last):
-  File "<string>", line 1, in ?
-ValueError: cache must between 0 and 1000
+  ...
+ValueError: object size must between 0 and 16384
 >>> _g.set_debug()
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -235,12 +227,12 @@ Traceback (most recent call last):
 ValueError: bit_index must be >= 0
 >>> _g.mpz(23).setbit(12,1,2,3)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes at most 2 arguments (4 given)
+  ...
+TypeError: setbit() expects 'mpz','int'[,'int'] arguments
 >>> _g.setbit(12,1,2,3)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes at most 3 arguments (4 given)
+  ...
+TypeError: setbit() expects 'mpz','int'[,'int'] arguments
 >>> _g.root(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -255,12 +247,12 @@ Traceback (most recent call last):
 ValueError: root of negative number
 >>> _g.digits(3.14)
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: argument can not be converted to mpz
+  ...
+TypeError: digits() expects 'mpz',['int'] arguments
 >>> _g.digits(3,'peep')
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: an integer is required
+  ...
+TypeError: digits() expects 'mpz',['int'] arguments
 >>> _g.fdigits(3.14,'peep')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -275,8 +267,8 @@ Traceback (most recent call last):
 TypeError: an integer is required
 >>> _g.mpz(3).digits('bu')
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: an integer is required
+  ...
+TypeError: digits() expects 'mpz',['int'] arguments
 >>> _g.mpf(3).digits('bu')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -330,7 +322,7 @@ TypeError: gmpy.mpz(): base must be an integer
 >>> _g.mpz('bi',99)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: base for gmpy.mpz must be 0, 256, or in the interval 2 ... 36 .
+ValueError: base for gmpy.mpz must be 0, 256, or in the interval 2 ... 62 .
 >>> _g.mpz(1,2)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -382,7 +374,7 @@ TypeError: gmpy.mpf(): base must be an integer
 >>> _g.mpf('ba',0,99)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: base for gmpy.mpf must be 0, 256, or in the interval 2 ... 36 .
+ValueError: base for gmpy.mpf must be 0, 256, or in the interval 2 ... 62 .
 >>> _g.mpf(1,2,3)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -530,12 +522,18 @@ True
 
 def _test(chat=None):
     if chat:
-        print "Unit tests for gmpy 1.10 (extra cover)"
+        print "Unit tests for gmpy 1.17 (extra cover)"
         print "    running on Python", sys.version
         print
-        print "Testing gmpy %s (GMP %s) with default caching (%s, %s)" % (
-            (_g.version(), _g.gmp_version(), _g.get_zcache(),
-            _g.get_qcache(), _g.get_fcache()))
+        if _g.gmp_version():
+            print "Testing gmpy %s (GMP %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.gmp_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+        else:
+            print "Testing gmpy %s (MPIR %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.mpir_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+
     thismod = sys.modules.get(__name__)
     doctest.testmod(thismod, report=0)
 
