@@ -1,9 +1,9 @@
-# partial unit test for gmpy 1.11 mpq functionality
+# partial unit test for gmpy mpq functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.11
+
 r'''
 >>> filter(lambda x: not x.startswith('__'), dir(a))
-['_copy', 'binary', 'denom', 'digits', 'numer', 'qdiv', 'sign']
+['_copy', 'binary', 'denom', 'denominator', 'digits', 'numer', 'numerator', 'qdiv', 'sign']
 >>>
 '''
 
@@ -62,6 +62,10 @@ mpq(41,152)
 -1
 >>> z=b-b; z.sign()
 0
+>>> a.numer() == a.numerator
+True
+>>> a.denom() == a.denominator
+True
 >>> an=a.numer(); ad=a.denom();
 >>> an==0 or 1==a*_g.mpq(ad,an)
 1
@@ -183,11 +187,15 @@ gmpy.mpq(617,50)
 ...       if _g.mpq(i,j) != _g.mpq("%d/%d"%(i,j)):
 ...          print 'er1:',i,j; break
 ...       aa=_g.mpq(i,j); ai=aa.numer(); aj=aa.denom()
-...       if str(aa) != ("%d/%d"%(ai,aj)):
+...       if aj!=1 and str(aa) != ("%d/%d"%(ai,aj)):
 ...          print 'er2:',i,j,str(aa),("%d/%d"%(ai,aj)); break
-...       if repr(aa) != ("mpq(%d,%d)"%(ai,aj)):
-...          print 'er3:',i,j,repr(aa),("mpq(%d,%d)"%(ai,aj)); break
->>> fmo='_g.mpq('+a.numer().digits(16)+','+a.denom().digits(16)+')'
+...       if aj==1 and str(aa) != ("%d"%ai):
+...          print 'er3:',i,j,str(aa),"%d"%ai; break
+...       if aj!=1 and repr(aa) != ("mpq(%d,%d)"%(ai,aj)):
+...          print 'er4:',i,j,repr(aa),("mpq(%d,%d)"%(ai,aj)); break
+...       if aj==1 and repr(aa) != ("mpq(%d,%d)"%(ai,aj)):
+...          print 'er5:',i,j,repr(aa),"mpq(%d,%d)"%(ai,aj); break
+>>> fmo='_g.mpq('+hex(a.numer())+','+hex(a.denom())+')'
 >>> fmo
 '_g.mpq(0x29,0x98)'
 >>> eval(fmo)==a
@@ -306,7 +314,7 @@ mpq(12,5)
 
 def _test(chat=None):
     if chat:
-        print "Unit tests for gmpy 1.11 (mpq functionality)"
+        print "Unit tests for gmpy 1.17 (mpq functionality)"
         print "    running on Python",sys.version
         print
         if _g.gmp_version():
