@@ -1,11 +1,11 @@
-# partial unit test for gmpy 1.11 mpz functionality
+# partial unit test for gmpy mpz functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.11
+
 r'''
 >>> filter(lambda x: not x.startswith('_'), dir(_g))
 ['binary', 'bincoef', 'bit_length', 'cdivmod', 'ceil', 'comb', 'denom', 'digits', 'divexact', 'divm', 'f2q', 'fac', 'fbinary', 'fdigits', 'fdivmod', 'fib', 'floor', 'fround', 'fsign', 'fsqrt', 'gcd', 'gcdext', 'get_cache', 'getbit', 'getprec', 'getrprec', 'gmp_limbsize', 'gmp_version', 'hamdist', 'invert', 'is_power', 'is_prime', 'is_square', 'jacobi', 'kronecker', 'lcm', 'legendre', 'license', 'lowbits', 'mpf', 'mpir_version', 'mpq', 'mpz', 'next_prime', 'numdigits', 'numer', 'pi', 'popcount', 'qbinary', 'qdigits', 'qdiv', 'qsign', 'rand', 'reldiff', 'remove', 'root', 'scan0', 'scan1', 'set_cache', 'set_debug', 'set_fcoform', 'set_minprec', 'set_tagoff', 'setbit', 'sign', 'sqrt', 'sqrtrem', 'tdivmod', 'trunc', 'version']
 >>> filter(lambda x: not x.startswith('__'), dir(a))
-['_copy', 'binary', 'bincoef', 'bit_length', 'cdivmod', 'comb', 'digits', 'divexact', 'fdivmod', 'getbit', 'hamdist', 'invert', 'is_power', 'is_prime', 'is_square', 'jacobi', 'kronecker', 'legendre', 'lowbits', 'next_prime', 'numdigits', 'popcount', 'qdiv', 'remove', 'root', 'scan0', 'scan1', 'setbit', 'sign', 'sqrt', 'sqrtrem', 'tdivmod']
+['_copy', 'binary', 'bincoef', 'bit_length', 'comb', 'digits', 'getbit', 'hamdist', 'invert', 'is_power', 'is_prime', 'is_square', 'jacobi', 'kronecker', 'legendre', 'lowbits', 'next_prime', 'numdigits', 'popcount', 'qdiv', 'remove', 'root', 'scan0', 'scan1', 'setbit', 'sign', 'sqrt', 'sqrtrem']
 >>>
 '''
 import warnings
@@ -186,6 +186,10 @@ r'''
 >>> c=a*b
 >>> _g.divexact(c,a)
 mpz(789789789789789789789789L)
+>>> _g.divexact(10,0)
+Traceback (most recent call last):
+  ...
+ZeroDivisionError: divexact() division by 0
 >>>
 '''
 
@@ -215,6 +219,18 @@ r'''
 (mpz(-3), mpz(2))
 >>> _g.tdivmod(-17,-5)
 (mpz(3), mpz(-2))
+>>> _g.cdivmod(10,0)
+Traceback (most recent call last):
+  ...
+ZeroDivisionError: cdivmod() division by 0
+>>> _g.fdivmod(10,0)
+Traceback (most recent call last):
+  ...
+ZeroDivisionError: fdivmod() division by 0
+>>> _g.tdivmod(10,0)
+Traceback (most recent call last):
+  ...
+ZeroDivisionError: tdivmod() division by 0
 '''
 
 __test__['cmpr']=\
@@ -564,21 +580,26 @@ mpz(123)
 mpz(587)
 >>> _g.mpz('1001001011',2).digits(2)
 '1001001011'
->>> for i in range(2,37):
+>>> for i in range(2,63):
 ...     print a.digits(i),
 ...     if i%6==0: print
 ...
 1111011 11120 1323 443 323
-234 0173 146 123 102 a3
-96 8b 83 0x7b 74 6f
+234 173 146 123 102 a3
+96 8b 83 7b 74 6f
 69 63 5i 5d 58 53
 4n 4j 4f 4b 47 43
 3u 3r 3o 3l 3i 3f
->>> print a.digits(37)
+3C 39 36 33 30 2d
+2b 2Z 2X 2V 2T 2R
+2P 2N 2L 2J 2H 2F
+2D 2B 29 27 25 23
+21 1z
+>>> print a.digits(63)
 Traceback (innermost last):
   File "<stdin>", line 1, in ?
     print a.digits(37)
-ValueError: base must be either 0 or in the interval 2 ... 36
+ValueError: base must be either 0 or in the interval 2 ... 62
 >>> _g.set_tagoff(0)
 1
 >>> a
@@ -621,7 +642,7 @@ mpz(573406620562849222387053L)
 573406620562849222387053L
 >>> divmod(z,a)
 (mpz(4661842443600400182008L), mpz(69))
->>> for i in range(2,37):
+>>> for i in range(2,63):
 ...    print i,z.numdigits(i),
 ...    if i%6==0: print
 ...
@@ -631,6 +652,11 @@ mpz(573406620562849222387053L)
 19 19 20 19 21 18 22 18 23 18 24 18
 25 18 26 17 27 17 28 17 29 17 30 17
 31 16 32 16 33 16 34 16 35 16 36 16
+37 16 38 16 39 15 40 15 41 15 42 15
+43 15 44 15 45 15 46 15 47 15 48 15
+49 15 50 14 51 14 52 14 53 14 54 14
+55 14 56 14 57 14 58 14 59 14 60 14
+61 14 62 14
 >>> _g.numdigits(23)
 2
 >>> _g.numdigits(23,2)
@@ -638,7 +664,7 @@ mpz(573406620562849222387053L)
 >>> _g.numdigits(23,99)
 Traceback (most recent call last):
   File "<string>", line 1, in ?
-ValueError: base must be either 0 or in the interval 2 ... 36
+ValueError: base must be either 0 or in the interval 2 ... 62
 >>> hash(a)
 123
 >>> hash(b)
@@ -767,7 +793,7 @@ ValueError: sqrt of negative number
 >>> _g.remove(3,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: factor must be > 0
+ValueError: factor must be > 1
 >>> _g.remove(3)
 Traceback (innermost last):
   ...
@@ -876,7 +902,7 @@ def _test(chat=None):
             del(__test__["special"])
 
     if chat:
-        print "Unit tests for gmpy 1.11 (mpz functionality)"
+        print "Unit tests for gmpy 1.17 (mpz functionality)"
         print "    running on Python %s" % sys.version
         print
         if _g.gmp_version():
