@@ -2,9 +2,10 @@
 # note: broken in Python 2.4.0 due to a 2.4.0 bug, please update to 2.4.1
 #       or better to allow decimal/most-anything-else interoperability!-)
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.11
+
+# Hack to remove the '__dir__' attribute introduced in Python 3.3
 r'''
->>> dir(f)
+>>> list([x for x in dir(f) if x != '__dir__'])
 ['__abs__', '__add__', '__bool__', '__class__', '__delattr__', '__divmod__', '__doc__', '__eq__', '__float__', '__floordiv__', '__format__', '__ge__', '__getattribute__', '__gt__', '__hash__', '__init__', '__int__', '__le__', '__lt__', '__mod__', '__mul__', '__ne__', '__neg__', '__new__', '__pos__', '__pow__', '__radd__', '__rdivmod__', '__reduce__', '__reduce_ex__', '__repr__', '__rfloordiv__', '__rmod__', '__rmul__', '__rpow__', '__rsub__', '__rtruediv__', '__setattr__', '__sizeof__', '__str__', '__sub__', '__subclasshook__', '__truediv__', '_copy', 'binary', 'ceil', 'digits', 'f2q', 'floor', 'getprec', 'getrprec', 'qdiv', 'reldiff', 'round', 'setprec', 'sign', 'sqrt', 'trunc']
 >>>
 '''
@@ -86,7 +87,7 @@ def _test(chat=None):
         print("  No point in testing, therefore -- please upgrade your Python!")
         return 0, 0
     if chat:
-        print("Unit tests for gmpy 1.11 (decimal interoperation)")
+        print("Unit tests for gmpy 1.17 (decimal interoperation)")
         print("    running on Python", sys.version)
         print()
         if _g.gmp_version():
