@@ -1,8 +1,9 @@
-# partial unit test for gmpy 1.11 mpf functionality
+# partial unit test for gmpy mpf functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.11
+
+# Hack to remove the '__dir__' attribute introduced in Python 3.3
 r'''
->>> dir(a)
+>>> list([x for x in dir(a) if x != '__dir__'])
 ['__abs__', '__add__', '__bool__', '__class__', '__delattr__', '__divmod__', '__doc__', '__eq__', '__float__', '__floordiv__', '__format__', '__ge__', '__getattribute__', '__gt__', '__hash__', '__init__', '__int__', '__le__', '__lt__', '__mod__', '__mul__', '__ne__', '__neg__', '__new__', '__pos__', '__pow__', '__radd__', '__rdivmod__', '__reduce__', '__reduce_ex__', '__repr__', '__rfloordiv__', '__rmod__', '__rmul__', '__rpow__', '__rsub__', '__rtruediv__', '__setattr__', '__sizeof__', '__str__', '__sub__', '__subclasshook__', '__truediv__', '_copy', 'binary', 'ceil', 'digits', 'f2q', 'floor', 'getprec', 'getrprec', 'qdiv', 'reldiff', 'round', 'setprec', 'sign', 'sqrt', 'trunc']
 >>>
 '''
@@ -290,7 +291,7 @@ mpf('3.39999999999999999998e0')
 >>> a.digits(1)
 Traceback (most recent call last):
   File "<string>", line 1, in ?
-ValueError: base must be either 0 or in the interval 2 ... 36
+ValueError: base must be either 0 or in the interval 2 ... 62
 >>> a.digits(2,-1)
 Traceback (most recent call last):
   File "<string>", line 1, in ?
@@ -399,7 +400,7 @@ b'\x085\x00\x00\x00\x01\x00\x00\x00\x02'
 
 def _test(chat=None):
     if chat:
-        print("Unit tests for gmpy 1.11 (mpf functionality)")
+        print("Unit tests for gmpy 1.17 (mpf functionality)")
         print("    running on Python %s" % sys.version)
         print()
         if _g.gmp_version():
@@ -419,6 +420,7 @@ def _test(chat=None):
 
     sav = sys.stdout
     class _Dummy:
+        encoding=None
         def write(self,*whatever):
             pass
     try:
