@@ -1,9 +1,10 @@
-# partial unit test for gmpy 1.11 mpq functionality
+# partial unit test for gmpy mpq functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.11
+
+# Hack to remove the '__dir__' attribute introduced in Python 3.3
 r'''
->>> dir(a)
-['__abs__', '__add__', '__bool__', '__class__', '__delattr__', '__divmod__', '__doc__', '__eq__', '__float__', '__floordiv__', '__format__', '__ge__', '__getattribute__', '__gt__', '__hash__', '__init__', '__int__', '__le__', '__lt__', '__mod__', '__mul__', '__ne__', '__neg__', '__new__', '__pos__', '__pow__', '__radd__', '__rdivmod__', '__reduce__', '__reduce_ex__', '__repr__', '__rfloordiv__', '__rmod__', '__rmul__', '__rpow__', '__rsub__', '__rtruediv__', '__setattr__', '__sizeof__', '__str__', '__sub__', '__subclasshook__', '__truediv__', '_copy', 'binary', 'denom', 'digits', 'numer', 'qdiv', 'sign']
+>>> list([x for x in dir(a) if x != '__dir__'])
+['__abs__', '__add__', '__bool__', '__class__', '__delattr__', '__divmod__', '__doc__', '__eq__', '__float__', '__floordiv__', '__format__', '__ge__', '__getattribute__', '__gt__', '__hash__', '__init__', '__int__', '__le__', '__lt__', '__mod__', '__mul__', '__ne__', '__neg__', '__new__', '__pos__', '__pow__', '__radd__', '__rdivmod__', '__reduce__', '__reduce_ex__', '__repr__', '__rfloordiv__', '__rmod__', '__rmul__', '__rpow__', '__rsub__', '__rtruediv__', '__setattr__', '__sizeof__', '__str__', '__sub__', '__subclasshook__', '__truediv__', '_copy', 'binary', 'denom', 'denominator', 'digits', 'numer', 'numerator', 'qdiv', 'sign']
 >>>
 '''
 
@@ -117,6 +118,10 @@ mpq(41,152)
 -1
 >>> z=b-b; z.sign()
 0
+>>> a.numer() == a.numerator
+True
+>>> a.denom() == a.denominator
+True
 >>> an=a.numer(); ad=a.denom();
 >>> an==0 or 1==a*_g.mpq(ad,an)
 1
@@ -208,11 +213,15 @@ gmpy.mpq(617,50)
 ...       if _g.mpq(i,j) != _g.mpq("%d/%d"%(i,j)):
 ...          print('er1:',i,j); break
 ...       aa=_g.mpq(i,j); ai=aa.numer(); aj=aa.denom()
-...       if str(aa) != ("%d/%d"%(ai,aj)):
+...       if aj!=1 and str(aa) != ("%d/%d"%(ai,aj)):
 ...          print('er2:',i,j,str(aa),("%d/%d"%(ai,aj))); break
-...       if repr(aa) != ("mpq(%d,%d)"%(ai,aj)):
-...          print('er3:',i,j,repr(aa),("mpq(%d,%d)"%(ai,aj))); break
->>> fmo='_g.mpq('+a.numer().digits(16)+','+a.denom().digits(16)+')'
+...       if aj==1 and str(aa) != ("%d"%ai):
+...          print('er3:',i,j,str(aa),"%d"%ai); break
+...       if aj!=1 and repr(aa) != ("mpq(%d,%d)"%(ai,aj)):
+...          print('er4:',i,j,repr(aa),("mpq(%d,%d)"%(ai,aj))); break
+...       if aj==1 and repr(aa) != ("mpq(%d,%d)"%(ai,aj)):
+...          print('er5:',i,j,repr(aa),"mpq(%d,%d)"%(ai,aj)); break
+>>> fmo='_g.mpq('+hex(a.numer())+','+hex(a.denom())+')'
 >>> fmo
 '_g.mpq(0x29,0x98)'
 >>> eval(fmo)==a
@@ -276,14 +285,6 @@ r'''
 152
 >>> _g.mpq(ba,256)==-a
 1
->>> hash(a)==hash(_g.mpf(a))==hash(float(a))
-1
->>> hash(b)==hash(_g.mpf(b))==hash(float(b))
-1
->>> hash(-a)==hash(-_g.mpf(a))==hash(-float(a))
-1
->>> hash(-b)==hash(-_g.mpf(b))==hash(-float(b))
-1
 >>>
 '''
 
@@ -297,7 +298,7 @@ mpq(4,9)
 mpq(27,8)
 >>> _g.mpq(8,27)**_g.mpq('-2/3')
 mpq(9,4)
->>> print(float(_g.mpf('0.2')**2))
+>>> print(float("%.14f" % _g.mpf('0.2')**2))
 0.04
 >>> print(float(_g.mpf('0.2')**-2))
 25.0
@@ -339,7 +340,7 @@ mpq(12,5)
 
 def _test(chat=None):
     if chat:
-        print("Unit tests for gmpy 1.11 (mpq functionality)")
+        print("Unit tests for gmpy 1.17 (mpq functionality)")
         print("    running on Python",sys.version)
         print()
         if _g.gmp_version():
@@ -359,6 +360,7 @@ def _test(chat=None):
 
     sav = sys.stdout
     class _Dummy:
+        encoding = None
         def write(self,*whatever):
             pass
     try:
