@@ -1,6 +1,6 @@
-# partial unit test for gmpy 1.11 rand functionality
+# partial unit test for gmpy rand functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.11
+
 r'''
 >>> r
 <built-in function rand>
@@ -74,9 +74,9 @@ lpourtekn
 enukotlpr
 >>> r('seed',sav)
 >>> for i in range(3):
-...     print(float(r('floa')))
+...     print("%.12f" % float(r('floa')))
 ...
-0.44833278656
+0.448332786560
 0.547296524048
 0.895370483398
 >>> r('seed',sav)
@@ -127,7 +127,7 @@ if sys.version<'2.4':
 
 def _test(chat=None):
     if chat:
-        print("Unit tests for gmpy 1.11 (rand functionality)")
+        print("Unit tests for gmpy 1.17 (rand functionality)")
         print("    running on Python %s" % sys.version)
         print("")
         if _g.gmp_version():
